pub enum ReceiveErrorTimeout {
Closed,
SendClosed,
Timeout,
}Expand description
Error type for channel receive operations with timeout
Variants
Closed
Indicates that the channel is closed on both sides with a call to
close()
SendClosed
Indicates that all sender instances are dropped and the channel is closed from the send side
Timeout
Indicates that channel operation reached timeout and is canceled